@@ -111,7 +111,7 @@ void ScreenSing::setupVocals() {
 			selectedTracks.push_back(vocal);
 			shownTracks.insert(vocal);
 		}
-		if (shownTracks.size() > 2) throw std::runtime_error("Too many tracks chosen. Only two vocal tracks can be used simultaneously.");
+		//if (shownTracks.size() > 2) throw std::runtime_error("Too many tracks chosen. Only two vocal tracks can be used simultaneously.");
 		for (auto const& trk: shownTracks) m_layout_singer.push_back(new LayoutSinger(*trk, m_database, theme));
 		// Note: Engine maps tracks with analyzers 1:1. If user doesn't have mics, we still want to have singer layout enabled but without engine...
 		if (!analyzers.empty()) m_engine.reset(new Engine(m_audio, selectedTracks, m_database));
@@ -348,7 +348,12 @@ void ScreenSing::manageEvent(SDL_Event event) {
 	double time = m_audio.getPosition();
 	SDL_Scancode key = event.key.keysym.scancode;
 	// Ctrl combinations that can be used while performing (not when score dialog is displayed)
-	if (event.type == SDL_KEYDOWN && (event.key.keysym.mod & KMOD_CTRL) && !m_score_window.get()) {
+	if (event.type == SDL_KEYDOWN && (event.key.keysym.mod & KMOD_LCTRL) && !m_score_window.get()) {
+		if (key == SDL_SCANCODE_C) {
+			m_audio.toggleCenterChannelSuppressor();
+			++config["audio/suppress_center_channel"];
+			dispInFlash(config["audio/suppress_center_channel"]);
+		}
 		if (key == SDL_SCANCODE_S) m_audio.toggleSynth(m_song->getVocalTrack(m_selectedTrack).notes);
 		if (key == SDL_SCANCODE_V) m_audio.streamFade("vocals", event.key.keysym.mod & KMOD_SHIFT ? 1.0 : 0.0);
 		if (key == SDL_SCANCODE_K)  { // Toggle karaoke mode
@@ -368,12 +373,12 @@ void ScreenSing::manageEvent(SDL_Event event) {
 			if (m_cam) { dispInFlash(++config["graphic/webcam"]); m_cam->pause(!config["graphic/webcam"].b()); }
 		}
 		// Latency settings
-		if (key == SDL_SCANCODE_F1) dispInFlash(--config["audio/video_delay"]);
-		if (key == SDL_SCANCODE_F2) dispInFlash(++config["audio/video_delay"]);
-		if (key == SDL_SCANCODE_F3) dispInFlash(--config["audio/round-trip"]);
-		if (key == SDL_SCANCODE_F4) dispInFlash(++config["audio/round-trip"]);
-		if (key == SDL_SCANCODE_F5) dispInFlash(--config["audio/controller_delay"]);
-		if (key == SDL_SCANCODE_F6) dispInFlash(++config["audio/controller_delay"]);
+		if (key == SDL_SCANCODE_COMMA) dispInFlash(--config["audio/video_delay"]);
+		if (key == SDL_SCANCODE_PERIOD) dispInFlash(++config["audio/video_delay"]);
+		if (key == SDL_SCANCODE_MINUS) dispInFlash(--config["audio/round-trip"]);
+		if (key == SDL_SCANCODE_EQUALS) dispInFlash(++config["audio/round-trip"]);
+		if (key == SDL_SCANCODE_LEFTBRACKET) dispInFlash(--config["audio/controller_delay"]);
+		if (key == SDL_SCANCODE_RIGHTBRACKET) dispInFlash(++config["audio/controller_delay"]);
 		bool seekback = false;
 
 		if (m_song->danceTracks.empty()) { // Seeking backwards is currently not permitted for dance songs
@@ -573,7 +578,7 @@ void ScreenSing::drawMenu() {
 	if (m_menu.empty()) return;
 	// Some helper vars
 	ThemeInstrumentMenu& th = *m_menuTheme;
-	auto cur = static_cast<MenuOptions::const_iterator>(&m_menu.current());
+	const auto cur = &m_menu.current();
 	double w = m_menu.dimensions.w();
 	const float txth = th.option_selected.h();
 	const float step = txth * 0.85f;
@@ -590,7 +595,8 @@ void ScreenSing::drawMenu() {
 	for (MenuOptions::const_iterator it = m_menu.begin(); it != m_menu.end(); ++it) {
 		// Pick the font object
 		SvgTxtTheme* txt = &th.option_selected;
-		if (cur != it) txt = &(th.getCachedOption(it->getName()));
+		if (cur != &*it)
+			txt = &(th.getCachedOption(it->getName()));
 		// Set dimensions and draw
 		txt->dimensions.middle(x).center(y);
 		txt->draw(it->getName());
@@ -692,7 +698,7 @@ void ScoreWindow::draw() {
 	for (Database::cur_scores_t::const_iterator p = m_database.scores.begin(); p != m_database.scores.end(); ++p, ++i) {
 		int score = p->score;
 		ColorTrans c(p->color);
-		double x = -0.12 + spacing * (0.5 + i - 0.5 * m_database.scores.size());
+		double x = spacing * (0.5 + i - 0.5 * m_database.scores.size());
 		m_scoreBar.dimensions.fixedWidth(0.09).middle(x).bottom(0.20);
 		m_scoreBar.draw(score / 10000.0);
 		m_score_text.render(boost::lexical_cast<std::string>(score));
