@@ -199,7 +199,7 @@ void ScreenSongs::update() {
 	// Clear the old content and load new content if available
 	m_songbg.reset(); m_video.reset();
 	double pstart = (!m_jukebox && song ? song->preview_start : 0.0);
-	m_audio.playMusic(music, true, 2.0, pstart);
+	m_audio.playMusic(music, true, 1.0, pstart);
 	if (song) {
 		fs::path const& background = song->background.empty() ? song->cover : song->background;
 		if (!background.empty()) try { m_songbg.reset(new Surface(background)); } catch (std::exception const&) {}
@@ -478,7 +478,7 @@ void ScreenSongs::drawMenu() {
 	if (m_menu.empty()) return;
 	// Some helper vars
 	ThemeInstrumentMenu& th = *m_menuTheme;
-	auto cur = static_cast<MenuOptions::const_iterator>(&m_menu.current());
+	const auto cur = &m_menu.current();
 	double w = m_menu.dimensions.w();
 	const float txth = th.option_selected.h();
 	const float step = txth * 0.85f;
@@ -493,7 +493,8 @@ void ScreenSongs::drawMenu() {
 	for (MenuOptions::const_iterator it = m_menu.begin(); it != m_menu.end(); ++it) {
 		// Pick the font object
 		SvgTxtTheme* txt = &th.option_selected;
-		if (cur != it) txt = &(th.getCachedOption(it->getName()));
+		if (cur != &*it)
+			txt = &(th.getCachedOption(it->getName()));
 		// Set dimensions and draw
 		txt->dimensions.middle(x).center(y);
 		txt->draw(it->getName());
